# coding: utf-8

"""
    Agent Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
import pprint
from pydantic import BaseModel, ConfigDict, Field, StrictStr, ValidationError, field_validator
from typing import Any, List, Optional
from asteroid_odyssey.models.agents_execution_agent_query_context_completed_details import AgentsExecutionAgentQueryContextCompletedDetails
from asteroid_odyssey.models.agents_execution_browser_run_code_completed_details import AgentsExecutionBrowserRunCodeCompletedDetails
from asteroid_odyssey.models.agents_execution_element_file_upload_completed_details import AgentsExecutionElementFileUploadCompletedDetails
from asteroid_odyssey.models.agents_execution_ext_api_call_completed_details import AgentsExecutionExtApiCallCompletedDetails
from asteroid_odyssey.models.agents_execution_ext_get_mail_completed_details import AgentsExecutionExtGetMailCompletedDetails
from asteroid_odyssey.models.agents_execution_file_list_completed_details import AgentsExecutionFileListCompletedDetails
from asteroid_odyssey.models.agents_execution_file_read_completed_details import AgentsExecutionFileReadCompletedDetails
from asteroid_odyssey.models.agents_execution_file_stage_completed_details import AgentsExecutionFileStageCompletedDetails
from asteroid_odyssey.models.agents_execution_nav_to_completed_details import AgentsExecutionNavToCompletedDetails
from asteroid_odyssey.models.agents_execution_obs_snapshot_with_selectors_completed_details import AgentsExecutionObsSnapshotWithSelectorsCompletedDetails
from asteroid_odyssey.models.agents_execution_scratchpad_read_completed_details import AgentsExecutionScratchpadReadCompletedDetails
from asteroid_odyssey.models.agents_execution_scratchpad_write_completed_details import AgentsExecutionScratchpadWriteCompletedDetails
from asteroid_odyssey.models.agents_execution_script_eval_completed_details import AgentsExecutionScriptEvalCompletedDetails
from asteroid_odyssey.models.agents_execution_script_hybrid_playwright_completed_details import AgentsExecutionScriptHybridPlaywrightCompletedDetails
from asteroid_odyssey.models.agents_execution_script_pad_run_function_completed_details import AgentsExecutionScriptPadRunFunctionCompletedDetails
from asteroid_odyssey.models.agents_execution_script_playwright_completed_details import AgentsExecutionScriptPlaywrightCompletedDetails
from asteroid_odyssey.models.agents_execution_scriptpad_read_completed_details import AgentsExecutionScriptpadReadCompletedDetails
from asteroid_odyssey.models.agents_execution_scriptpad_search_replace_completed_details import AgentsExecutionScriptpadSearchReplaceCompletedDetails
from asteroid_odyssey.models.agents_execution_scriptpad_write_completed_details import AgentsExecutionScriptpadWriteCompletedDetails
from asteroid_odyssey.models.agents_execution_util_get_datetime_completed_details import AgentsExecutionUtilGetDatetimeCompletedDetails
from pydantic import StrictStr, Field
from typing import Union, List, Set, Optional, Dict
from typing_extensions import Literal, Self

AGENTSEXECUTIONACTIVITYACTIONCOMPLETEDINFO_ONE_OF_SCHEMAS = ["AgentsExecutionAgentQueryContextCompletedDetails", "AgentsExecutionBrowserRunCodeCompletedDetails", "AgentsExecutionElementFileUploadCompletedDetails", "AgentsExecutionExtApiCallCompletedDetails", "AgentsExecutionExtGetMailCompletedDetails", "AgentsExecutionFileListCompletedDetails", "AgentsExecutionFileReadCompletedDetails", "AgentsExecutionFileStageCompletedDetails", "AgentsExecutionNavToCompletedDetails", "AgentsExecutionObsSnapshotWithSelectorsCompletedDetails", "AgentsExecutionScratchpadReadCompletedDetails", "AgentsExecutionScratchpadWriteCompletedDetails", "AgentsExecutionScriptEvalCompletedDetails", "AgentsExecutionScriptHybridPlaywrightCompletedDetails", "AgentsExecutionScriptPadRunFunctionCompletedDetails", "AgentsExecutionScriptPlaywrightCompletedDetails", "AgentsExecutionScriptpadReadCompletedDetails", "AgentsExecutionScriptpadSearchReplaceCompletedDetails", "AgentsExecutionScriptpadWriteCompletedDetails", "AgentsExecutionUtilGetDatetimeCompletedDetails"]

class AgentsExecutionActivityActionCompletedInfo(BaseModel):
    """
    AgentsExecutionActivityActionCompletedInfo
    """
    # data type: AgentsExecutionExtApiCallCompletedDetails
    oneof_schema_1_validator: Optional[AgentsExecutionExtApiCallCompletedDetails] = None
    # data type: AgentsExecutionScratchpadReadCompletedDetails
    oneof_schema_2_validator: Optional[AgentsExecutionScratchpadReadCompletedDetails] = None
    # data type: AgentsExecutionScratchpadWriteCompletedDetails
    oneof_schema_3_validator: Optional[AgentsExecutionScratchpadWriteCompletedDetails] = None
    # data type: AgentsExecutionScriptPlaywrightCompletedDetails
    oneof_schema_4_validator: Optional[AgentsExecutionScriptPlaywrightCompletedDetails] = None
    # data type: AgentsExecutionScriptHybridPlaywrightCompletedDetails
    oneof_schema_5_validator: Optional[AgentsExecutionScriptHybridPlaywrightCompletedDetails] = None
    # data type: AgentsExecutionBrowserRunCodeCompletedDetails
    oneof_schema_6_validator: Optional[AgentsExecutionBrowserRunCodeCompletedDetails] = None
    # data type: AgentsExecutionScriptEvalCompletedDetails
    oneof_schema_7_validator: Optional[AgentsExecutionScriptEvalCompletedDetails] = None
    # data type: AgentsExecutionFileReadCompletedDetails
    oneof_schema_8_validator: Optional[AgentsExecutionFileReadCompletedDetails] = None
    # data type: AgentsExecutionFileListCompletedDetails
    oneof_schema_9_validator: Optional[AgentsExecutionFileListCompletedDetails] = None
    # data type: AgentsExecutionFileStageCompletedDetails
    oneof_schema_10_validator: Optional[AgentsExecutionFileStageCompletedDetails] = None
    # data type: AgentsExecutionElementFileUploadCompletedDetails
    oneof_schema_11_validator: Optional[AgentsExecutionElementFileUploadCompletedDetails] = None
    # data type: AgentsExecutionExtGetMailCompletedDetails
    oneof_schema_12_validator: Optional[AgentsExecutionExtGetMailCompletedDetails] = None
    # data type: AgentsExecutionScriptPadRunFunctionCompletedDetails
    oneof_schema_13_validator: Optional[AgentsExecutionScriptPadRunFunctionCompletedDetails] = None
    # data type: AgentsExecutionScriptpadReadCompletedDetails
    oneof_schema_14_validator: Optional[AgentsExecutionScriptpadReadCompletedDetails] = None
    # data type: AgentsExecutionScriptpadWriteCompletedDetails
    oneof_schema_15_validator: Optional[AgentsExecutionScriptpadWriteCompletedDetails] = None
    # data type: AgentsExecutionScriptpadSearchReplaceCompletedDetails
    oneof_schema_16_validator: Optional[AgentsExecutionScriptpadSearchReplaceCompletedDetails] = None
    # data type: AgentsExecutionObsSnapshotWithSelectorsCompletedDetails
    oneof_schema_17_validator: Optional[AgentsExecutionObsSnapshotWithSelectorsCompletedDetails] = None
    # data type: AgentsExecutionUtilGetDatetimeCompletedDetails
    oneof_schema_18_validator: Optional[AgentsExecutionUtilGetDatetimeCompletedDetails] = None
    # data type: AgentsExecutionNavToCompletedDetails
    oneof_schema_19_validator: Optional[AgentsExecutionNavToCompletedDetails] = None
    # data type: AgentsExecutionAgentQueryContextCompletedDetails
    oneof_schema_20_validator: Optional[AgentsExecutionAgentQueryContextCompletedDetails] = None
    actual_instance: Optional[Union[AgentsExecutionAgentQueryContextCompletedDetails, AgentsExecutionBrowserRunCodeCompletedDetails, AgentsExecutionElementFileUploadCompletedDetails, AgentsExecutionExtApiCallCompletedDetails, AgentsExecutionExtGetMailCompletedDetails, AgentsExecutionFileListCompletedDetails, AgentsExecutionFileReadCompletedDetails, AgentsExecutionFileStageCompletedDetails, AgentsExecutionNavToCompletedDetails, AgentsExecutionObsSnapshotWithSelectorsCompletedDetails, AgentsExecutionScratchpadReadCompletedDetails, AgentsExecutionScratchpadWriteCompletedDetails, AgentsExecutionScriptEvalCompletedDetails, AgentsExecutionScriptHybridPlaywrightCompletedDetails, AgentsExecutionScriptPadRunFunctionCompletedDetails, AgentsExecutionScriptPlaywrightCompletedDetails, AgentsExecutionScriptpadReadCompletedDetails, AgentsExecutionScriptpadSearchReplaceCompletedDetails, AgentsExecutionScriptpadWriteCompletedDetails, AgentsExecutionUtilGetDatetimeCompletedDetails]] = None
    one_of_schemas: Set[str] = { "AgentsExecutionAgentQueryContextCompletedDetails", "AgentsExecutionBrowserRunCodeCompletedDetails", "AgentsExecutionElementFileUploadCompletedDetails", "AgentsExecutionExtApiCallCompletedDetails", "AgentsExecutionExtGetMailCompletedDetails", "AgentsExecutionFileListCompletedDetails", "AgentsExecutionFileReadCompletedDetails", "AgentsExecutionFileStageCompletedDetails", "AgentsExecutionNavToCompletedDetails", "AgentsExecutionObsSnapshotWithSelectorsCompletedDetails", "AgentsExecutionScratchpadReadCompletedDetails", "AgentsExecutionScratchpadWriteCompletedDetails", "AgentsExecutionScriptEvalCompletedDetails", "AgentsExecutionScriptHybridPlaywrightCompletedDetails", "AgentsExecutionScriptPadRunFunctionCompletedDetails", "AgentsExecutionScriptPlaywrightCompletedDetails", "AgentsExecutionScriptpadReadCompletedDetails", "AgentsExecutionScriptpadSearchReplaceCompletedDetails", "AgentsExecutionScriptpadWriteCompletedDetails", "AgentsExecutionUtilGetDatetimeCompletedDetails" }

    model_config = ConfigDict(
        validate_assignment=True,
        protected_namespaces=(),
    )


    discriminator_value_class_map: Dict[str, str] = {
    }

    def __init__(self, *args, **kwargs) -> None:
        if args:
            if len(args) > 1:
                raise ValueError("If a position argument is used, only 1 is allowed to set `actual_instance`")
            if kwargs:
                raise ValueError("If a position argument is used, keyword arguments cannot be used.")
            super().__init__(actual_instance=args[0])
        else:
            super().__init__(**kwargs)

    @field_validator('actual_instance')
    def actual_instance_must_validate_oneof(cls, v):
        instance = AgentsExecutionActivityActionCompletedInfo.model_construct()
        error_messages = []
        match = 0
        # validate data type: AgentsExecutionExtApiCallCompletedDetails
        if not isinstance(v, AgentsExecutionExtApiCallCompletedDetails):
            error_messages.append(f"Error! Input type `{type(v)}` is not `AgentsExecutionExtApiCallCompletedDetails`")
        else:
            match += 1
        # validate data type: AgentsExecutionScratchpadReadCompletedDetails
        if not isinstance(v, AgentsExecutionScratchpadReadCompletedDetails):
            error_messages.append(f"Error! Input type `{type(v)}` is not `AgentsExecutionScratchpadReadCompletedDetails`")
        else:
            match += 1
        # validate data type: AgentsExecutionScratchpadWriteCompletedDetails
        if not isinstance(v, AgentsExecutionScratchpadWriteCompletedDetails):
            error_messages.append(f"Error! Input type `{type(v)}` is not `AgentsExecutionScratchpadWriteCompletedDetails`")
        else:
            match += 1
        # validate data type: AgentsExecutionScriptPlaywrightCompletedDetails
        if not isinstance(v, AgentsExecutionScriptPlaywrightCompletedDetails):
            error_messages.append(f"Error! Input type `{type(v)}` is not `AgentsExecutionScriptPlaywrightCompletedDetails`")
        else:
            match += 1
        # validate data type: AgentsExecutionScriptHybridPlaywrightCompletedDetails
        if not isinstance(v, AgentsExecutionScriptHybridPlaywrightCompletedDetails):
            error_messages.append(f"Error! Input type `{type(v)}` is not `AgentsExecutionScriptHybridPlaywrightCompletedDetails`")
        else:
            match += 1
        # validate data type: AgentsExecutionBrowserRunCodeCompletedDetails
        if not isinstance(v, AgentsExecutionBrowserRunCodeCompletedDetails):
            error_messages.append(f"Error! Input type `{type(v)}` is not `AgentsExecutionBrowserRunCodeCompletedDetails`")
        else:
            match += 1
        # validate data type: AgentsExecutionScriptEvalCompletedDetails
        if not isinstance(v, AgentsExecutionScriptEvalCompletedDetails):
            error_messages.append(f"Error! Input type `{type(v)}` is not `AgentsExecutionScriptEvalCompletedDetails`")
        else:
            match += 1
        # validate data type: AgentsExecutionFileReadCompletedDetails
        if not isinstance(v, AgentsExecutionFileReadCompletedDetails):
            error_messages.append(f"Error! Input type `{type(v)}` is not `AgentsExecutionFileReadCompletedDetails`")
        else:
            match += 1
        # validate data type: AgentsExecutionFileListCompletedDetails
        if not isinstance(v, AgentsExecutionFileListCompletedDetails):
            error_messages.append(f"Error! Input type `{type(v)}` is not `AgentsExecutionFileListCompletedDetails`")
        else:
            match += 1
        # validate data type: AgentsExecutionFileStageCompletedDetails
        if not isinstance(v, AgentsExecutionFileStageCompletedDetails):
            error_messages.append(f"Error! Input type `{type(v)}` is not `AgentsExecutionFileStageCompletedDetails`")
        else:
            match += 1
        # validate data type: AgentsExecutionElementFileUploadCompletedDetails
        if not isinstance(v, AgentsExecutionElementFileUploadCompletedDetails):
            error_messages.append(f"Error! Input type `{type(v)}` is not `AgentsExecutionElementFileUploadCompletedDetails`")
        else:
            match += 1
        # validate data type: AgentsExecutionExtGetMailCompletedDetails
        if not isinstance(v, AgentsExecutionExtGetMailCompletedDetails):
            error_messages.append(f"Error! Input type `{type(v)}` is not `AgentsExecutionExtGetMailCompletedDetails`")
        else:
            match += 1
        # validate data type: AgentsExecutionScriptPadRunFunctionCompletedDetails
        if not isinstance(v, AgentsExecutionScriptPadRunFunctionCompletedDetails):
            error_messages.append(f"Error! Input type `{type(v)}` is not `AgentsExecutionScriptPadRunFunctionCompletedDetails`")
        else:
            match += 1
        # validate data type: AgentsExecutionScriptpadReadCompletedDetails
        if not isinstance(v, AgentsExecutionScriptpadReadCompletedDetails):
            error_messages.append(f"Error! Input type `{type(v)}` is not `AgentsExecutionScriptpadReadCompletedDetails`")
        else:
            match += 1
        # validate data type: AgentsExecutionScriptpadWriteCompletedDetails
        if not isinstance(v, AgentsExecutionScriptpadWriteCompletedDetails):
            error_messages.append(f"Error! Input type `{type(v)}` is not `AgentsExecutionScriptpadWriteCompletedDetails`")
        else:
            match += 1
        # validate data type: AgentsExecutionScriptpadSearchReplaceCompletedDetails
        if not isinstance(v, AgentsExecutionScriptpadSearchReplaceCompletedDetails):
            error_messages.append(f"Error! Input type `{type(v)}` is not `AgentsExecutionScriptpadSearchReplaceCompletedDetails`")
        else:
            match += 1
        # validate data type: AgentsExecutionObsSnapshotWithSelectorsCompletedDetails
        if not isinstance(v, AgentsExecutionObsSnapshotWithSelectorsCompletedDetails):
            error_messages.append(f"Error! Input type `{type(v)}` is not `AgentsExecutionObsSnapshotWithSelectorsCompletedDetails`")
        else:
            match += 1
        # validate data type: AgentsExecutionUtilGetDatetimeCompletedDetails
        if not isinstance(v, AgentsExecutionUtilGetDatetimeCompletedDetails):
            error_messages.append(f"Error! Input type `{type(v)}` is not `AgentsExecutionUtilGetDatetimeCompletedDetails`")
        else:
            match += 1
        # validate data type: AgentsExecutionNavToCompletedDetails
        if not isinstance(v, AgentsExecutionNavToCompletedDetails):
            error_messages.append(f"Error! Input type `{type(v)}` is not `AgentsExecutionNavToCompletedDetails`")
        else:
            match += 1
        # validate data type: AgentsExecutionAgentQueryContextCompletedDetails
        if not isinstance(v, AgentsExecutionAgentQueryContextCompletedDetails):
            error_messages.append(f"Error! Input type `{type(v)}` is not `AgentsExecutionAgentQueryContextCompletedDetails`")
        else:
            match += 1
        if match > 1:
            # more than 1 match
            raise ValueError("Multiple matches found when setting `actual_instance` in AgentsExecutionActivityActionCompletedInfo with oneOf schemas: AgentsExecutionAgentQueryContextCompletedDetails, AgentsExecutionBrowserRunCodeCompletedDetails, AgentsExecutionElementFileUploadCompletedDetails, AgentsExecutionExtApiCallCompletedDetails, AgentsExecutionExtGetMailCompletedDetails, AgentsExecutionFileListCompletedDetails, AgentsExecutionFileReadCompletedDetails, AgentsExecutionFileStageCompletedDetails, AgentsExecutionNavToCompletedDetails, AgentsExecutionObsSnapshotWithSelectorsCompletedDetails, AgentsExecutionScratchpadReadCompletedDetails, AgentsExecutionScratchpadWriteCompletedDetails, AgentsExecutionScriptEvalCompletedDetails, AgentsExecutionScriptHybridPlaywrightCompletedDetails, AgentsExecutionScriptPadRunFunctionCompletedDetails, AgentsExecutionScriptPlaywrightCompletedDetails, AgentsExecutionScriptpadReadCompletedDetails, AgentsExecutionScriptpadSearchReplaceCompletedDetails, AgentsExecutionScriptpadWriteCompletedDetails, AgentsExecutionUtilGetDatetimeCompletedDetails. Details: " + ", ".join(error_messages))
        elif match == 0:
            # no match
            raise ValueError("No match found when setting `actual_instance` in AgentsExecutionActivityActionCompletedInfo with oneOf schemas: AgentsExecutionAgentQueryContextCompletedDetails, AgentsExecutionBrowserRunCodeCompletedDetails, AgentsExecutionElementFileUploadCompletedDetails, AgentsExecutionExtApiCallCompletedDetails, AgentsExecutionExtGetMailCompletedDetails, AgentsExecutionFileListCompletedDetails, AgentsExecutionFileReadCompletedDetails, AgentsExecutionFileStageCompletedDetails, AgentsExecutionNavToCompletedDetails, AgentsExecutionObsSnapshotWithSelectorsCompletedDetails, AgentsExecutionScratchpadReadCompletedDetails, AgentsExecutionScratchpadWriteCompletedDetails, AgentsExecutionScriptEvalCompletedDetails, AgentsExecutionScriptHybridPlaywrightCompletedDetails, AgentsExecutionScriptPadRunFunctionCompletedDetails, AgentsExecutionScriptPlaywrightCompletedDetails, AgentsExecutionScriptpadReadCompletedDetails, AgentsExecutionScriptpadSearchReplaceCompletedDetails, AgentsExecutionScriptpadWriteCompletedDetails, AgentsExecutionUtilGetDatetimeCompletedDetails. Details: " + ", ".join(error_messages))
        else:
            return v

    @classmethod
    def from_dict(cls, obj: Union[str, Dict[str, Any]]) -> Self:
        return cls.from_json(json.dumps(obj))

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Returns the object represented by the json string"""
        instance = cls.model_construct()
        error_messages = []
        match = 0

        # deserialize data into AgentsExecutionExtApiCallCompletedDetails
        try:
            instance.actual_instance = AgentsExecutionExtApiCallCompletedDetails.from_json(json_str)
            match += 1
        except (ValidationError, ValueError) as e:
            error_messages.append(str(e))
        # deserialize data into AgentsExecutionScratchpadReadCompletedDetails
        try:
            instance.actual_instance = AgentsExecutionScratchpadReadCompletedDetails.from_json(json_str)
            match += 1
        except (ValidationError, ValueError) as e:
            error_messages.append(str(e))
        # deserialize data into AgentsExecutionScratchpadWriteCompletedDetails
        try:
            instance.actual_instance = AgentsExecutionScratchpadWriteCompletedDetails.from_json(json_str)
            match += 1
        except (ValidationError, ValueError) as e:
            error_messages.append(str(e))
        # deserialize data into AgentsExecutionScriptPlaywrightCompletedDetails
        try:
            instance.actual_instance = AgentsExecutionScriptPlaywrightCompletedDetails.from_json(json_str)
            match += 1
        except (ValidationError, ValueError) as e:
            error_messages.append(str(e))
        # deserialize data into AgentsExecutionScriptHybridPlaywrightCompletedDetails
        try:
            instance.actual_instance = AgentsExecutionScriptHybridPlaywrightCompletedDetails.from_json(json_str)
            match += 1
        except (ValidationError, ValueError) as e:
            error_messages.append(str(e))
        # deserialize data into AgentsExecutionBrowserRunCodeCompletedDetails
        try:
            instance.actual_instance = AgentsExecutionBrowserRunCodeCompletedDetails.from_json(json_str)
            match += 1
        except (ValidationError, ValueError) as e:
            error_messages.append(str(e))
        # deserialize data into AgentsExecutionScriptEvalCompletedDetails
        try:
            instance.actual_instance = AgentsExecutionScriptEvalCompletedDetails.from_json(json_str)
            match += 1
        except (ValidationError, ValueError) as e:
            error_messages.append(str(e))
        # deserialize data into AgentsExecutionFileReadCompletedDetails
        try:
            instance.actual_instance = AgentsExecutionFileReadCompletedDetails.from_json(json_str)
            match += 1
        except (ValidationError, ValueError) as e:
            error_messages.append(str(e))
        # deserialize data into AgentsExecutionFileListCompletedDetails
        try:
            instance.actual_instance = AgentsExecutionFileListCompletedDetails.from_json(json_str)
            match += 1
        except (ValidationError, ValueError) as e:
            error_messages.append(str(e))
        # deserialize data into AgentsExecutionFileStageCompletedDetails
        try:
            instance.actual_instance = AgentsExecutionFileStageCompletedDetails.from_json(json_str)
            match += 1
        except (ValidationError, ValueError) as e:
            error_messages.append(str(e))
        # deserialize data into AgentsExecutionElementFileUploadCompletedDetails
        try:
            instance.actual_instance = AgentsExecutionElementFileUploadCompletedDetails.from_json(json_str)
            match += 1
        except (ValidationError, ValueError) as e:
            error_messages.append(str(e))
        # deserialize data into AgentsExecutionExtGetMailCompletedDetails
        try:
            instance.actual_instance = AgentsExecutionExtGetMailCompletedDetails.from_json(json_str)
            match += 1
        except (ValidationError, ValueError) as e:
            error_messages.append(str(e))
        # deserialize data into AgentsExecutionScriptPadRunFunctionCompletedDetails
        try:
            instance.actual_instance = AgentsExecutionScriptPadRunFunctionCompletedDetails.from_json(json_str)
            match += 1
        except (ValidationError, ValueError) as e:
            error_messages.append(str(e))
        # deserialize data into AgentsExecutionScriptpadReadCompletedDetails
        try:
            instance.actual_instance = AgentsExecutionScriptpadReadCompletedDetails.from_json(json_str)
            match += 1
        except (ValidationError, ValueError) as e:
            error_messages.append(str(e))
        # deserialize data into AgentsExecutionScriptpadWriteCompletedDetails
        try:
            instance.actual_instance = AgentsExecutionScriptpadWriteCompletedDetails.from_json(json_str)
            match += 1
        except (ValidationError, ValueError) as e:
            error_messages.append(str(e))
        # deserialize data into AgentsExecutionScriptpadSearchReplaceCompletedDetails
        try:
            instance.actual_instance = AgentsExecutionScriptpadSearchReplaceCompletedDetails.from_json(json_str)
            match += 1
        except (ValidationError, ValueError) as e:
            error_messages.append(str(e))
        # deserialize data into AgentsExecutionObsSnapshotWithSelectorsCompletedDetails
        try:
            instance.actual_instance = AgentsExecutionObsSnapshotWithSelectorsCompletedDetails.from_json(json_str)
            match += 1
        except (ValidationError, ValueError) as e:
            error_messages.append(str(e))
        # deserialize data into AgentsExecutionUtilGetDatetimeCompletedDetails
        try:
            instance.actual_instance = AgentsExecutionUtilGetDatetimeCompletedDetails.from_json(json_str)
            match += 1
        except (ValidationError, ValueError) as e:
            error_messages.append(str(e))
        # deserialize data into AgentsExecutionNavToCompletedDetails
        try:
            instance.actual_instance = AgentsExecutionNavToCompletedDetails.from_json(json_str)
            match += 1
        except (ValidationError, ValueError) as e:
            error_messages.append(str(e))
        # deserialize data into AgentsExecutionAgentQueryContextCompletedDetails
        try:
            instance.actual_instance = AgentsExecutionAgentQueryContextCompletedDetails.from_json(json_str)
            match += 1
        except (ValidationError, ValueError) as e:
            error_messages.append(str(e))

        if match > 1:
            # more than 1 match
            raise ValueError("Multiple matches found when deserializing the JSON string into AgentsExecutionActivityActionCompletedInfo with oneOf schemas: AgentsExecutionAgentQueryContextCompletedDetails, AgentsExecutionBrowserRunCodeCompletedDetails, AgentsExecutionElementFileUploadCompletedDetails, AgentsExecutionExtApiCallCompletedDetails, AgentsExecutionExtGetMailCompletedDetails, AgentsExecutionFileListCompletedDetails, AgentsExecutionFileReadCompletedDetails, AgentsExecutionFileStageCompletedDetails, AgentsExecutionNavToCompletedDetails, AgentsExecutionObsSnapshotWithSelectorsCompletedDetails, AgentsExecutionScratchpadReadCompletedDetails, AgentsExecutionScratchpadWriteCompletedDetails, AgentsExecutionScriptEvalCompletedDetails, AgentsExecutionScriptHybridPlaywrightCompletedDetails, AgentsExecutionScriptPadRunFunctionCompletedDetails, AgentsExecutionScriptPlaywrightCompletedDetails, AgentsExecutionScriptpadReadCompletedDetails, AgentsExecutionScriptpadSearchReplaceCompletedDetails, AgentsExecutionScriptpadWriteCompletedDetails, AgentsExecutionUtilGetDatetimeCompletedDetails. Details: " + ", ".join(error_messages))
        elif match == 0:
            # no match
            raise ValueError("No match found when deserializing the JSON string into AgentsExecutionActivityActionCompletedInfo with oneOf schemas: AgentsExecutionAgentQueryContextCompletedDetails, AgentsExecutionBrowserRunCodeCompletedDetails, AgentsExecutionElementFileUploadCompletedDetails, AgentsExecutionExtApiCallCompletedDetails, AgentsExecutionExtGetMailCompletedDetails, AgentsExecutionFileListCompletedDetails, AgentsExecutionFileReadCompletedDetails, AgentsExecutionFileStageCompletedDetails, AgentsExecutionNavToCompletedDetails, AgentsExecutionObsSnapshotWithSelectorsCompletedDetails, AgentsExecutionScratchpadReadCompletedDetails, AgentsExecutionScratchpadWriteCompletedDetails, AgentsExecutionScriptEvalCompletedDetails, AgentsExecutionScriptHybridPlaywrightCompletedDetails, AgentsExecutionScriptPadRunFunctionCompletedDetails, AgentsExecutionScriptPlaywrightCompletedDetails, AgentsExecutionScriptpadReadCompletedDetails, AgentsExecutionScriptpadSearchReplaceCompletedDetails, AgentsExecutionScriptpadWriteCompletedDetails, AgentsExecutionUtilGetDatetimeCompletedDetails. Details: " + ", ".join(error_messages))
        else:
            return instance

    def to_json(self) -> str:
        """Returns the JSON representation of the actual instance"""
        if self.actual_instance is None:
            return "null"

        if hasattr(self.actual_instance, "to_json") and callable(self.actual_instance.to_json):
            return self.actual_instance.to_json()
        else:
            return json.dumps(self.actual_instance)

    def to_dict(self) -> Optional[Union[Dict[str, Any], AgentsExecutionAgentQueryContextCompletedDetails, AgentsExecutionBrowserRunCodeCompletedDetails, AgentsExecutionElementFileUploadCompletedDetails, AgentsExecutionExtApiCallCompletedDetails, AgentsExecutionExtGetMailCompletedDetails, AgentsExecutionFileListCompletedDetails, AgentsExecutionFileReadCompletedDetails, AgentsExecutionFileStageCompletedDetails, AgentsExecutionNavToCompletedDetails, AgentsExecutionObsSnapshotWithSelectorsCompletedDetails, AgentsExecutionScratchpadReadCompletedDetails, AgentsExecutionScratchpadWriteCompletedDetails, AgentsExecutionScriptEvalCompletedDetails, AgentsExecutionScriptHybridPlaywrightCompletedDetails, AgentsExecutionScriptPadRunFunctionCompletedDetails, AgentsExecutionScriptPlaywrightCompletedDetails, AgentsExecutionScriptpadReadCompletedDetails, AgentsExecutionScriptpadSearchReplaceCompletedDetails, AgentsExecutionScriptpadWriteCompletedDetails, AgentsExecutionUtilGetDatetimeCompletedDetails]]:
        """Returns the dict representation of the actual instance"""
        if self.actual_instance is None:
            return None

        if hasattr(self.actual_instance, "to_dict") and callable(self.actual_instance.to_dict):
            return self.actual_instance.to_dict()
        else:
            # primitive type
            return self.actual_instance

    def to_str(self) -> str:
        """Returns the string representation of the actual instance"""
        return pprint.pformat(self.model_dump())





# coding: utf-8

"""
    Agent Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import Field, StrictInt, StrictStr
from typing import Optional
from typing_extensions import Annotated
from asteroid_odyssey.models.agent_profile_pool_members_list200_response import AgentProfilePoolMembersList200Response
from asteroid_odyssey.models.agent_profile_pools_list200_response import AgentProfilePoolsList200Response
from asteroid_odyssey.models.agents_profile_add_profiles_to_pool_request import AgentsProfileAddProfilesToPoolRequest
from asteroid_odyssey.models.agents_profile_agent_profile_pool import AgentsProfileAgentProfilePool
from asteroid_odyssey.models.agents_profile_create_agent_profile_pool_request import AgentsProfileCreateAgentProfilePoolRequest
from asteroid_odyssey.models.agents_profile_pool_sort_field import AgentsProfilePoolSortField
from asteroid_odyssey.models.agents_profile_remove_profiles_from_pool_request import AgentsProfileRemoveProfilesFromPoolRequest
from asteroid_odyssey.models.agents_profile_update_agent_profile_pool_request import AgentsProfileUpdateAgentProfilePoolRequest
from asteroid_odyssey.models.common_sort_direction import CommonSortDirection

from asteroid_odyssey.api_client import ApiClient, RequestSerialized
from asteroid_odyssey.api_response import ApiResponse
from asteroid_odyssey.rest import RESTResponseType


class AgentProfilePoolsApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def agent_profile_pool_delete(
        self,
        pool_id: Annotated[StrictStr, Field(description="The ID of the agent profile pool")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> None:
        """Delete Agent Profile Pool

        Delete an agent profile pool

        :param pool_id: The ID of the agent profile pool (required)
        :type pool_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._agent_profile_pool_delete_serialize(
            pool_id=pool_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '204': None,
            '400': "CommonBadRequestErrorBody",
            '401': "CommonUnauthorizedErrorBody",
            '403': "CommonForbiddenErrorBody",
            '404': "CommonNotFoundErrorBody",
            '500': "CommonInternalServerErrorBody",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def agent_profile_pool_delete_with_http_info(
        self,
        pool_id: Annotated[StrictStr, Field(description="The ID of the agent profile pool")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[None]:
        """Delete Agent Profile Pool

        Delete an agent profile pool

        :param pool_id: The ID of the agent profile pool (required)
        :type pool_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._agent_profile_pool_delete_serialize(
            pool_id=pool_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '204': None,
            '400': "CommonBadRequestErrorBody",
            '401': "CommonUnauthorizedErrorBody",
            '403': "CommonForbiddenErrorBody",
            '404': "CommonNotFoundErrorBody",
            '500': "CommonInternalServerErrorBody",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def agent_profile_pool_delete_without_preload_content(
        self,
        pool_id: Annotated[StrictStr, Field(description="The ID of the agent profile pool")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Delete Agent Profile Pool

        Delete an agent profile pool

        :param pool_id: The ID of the agent profile pool (required)
        :type pool_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._agent_profile_pool_delete_serialize(
            pool_id=pool_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '204': None,
            '400': "CommonBadRequestErrorBody",
            '401': "CommonUnauthorizedErrorBody",
            '403': "CommonForbiddenErrorBody",
            '404': "CommonNotFoundErrorBody",
            '500': "CommonInternalServerErrorBody",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _agent_profile_pool_delete_serialize(
        self,
        pool_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if pool_id is not None:
            _path_params['poolId'] = pool_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'ApiKeyAuth'
        ]

        return self.api_client.param_serialize(
            method='DELETE',
            resource_path='/agent-profile-pools/{poolId}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def agent_profile_pool_get(
        self,
        pool_id: Annotated[StrictStr, Field(description="The ID of the agent profile pool")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> AgentsProfileAgentProfilePool:
        """Get Agent Profile Pool

        Get an agent profile pool by ID

        :param pool_id: The ID of the agent profile pool (required)
        :type pool_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._agent_profile_pool_get_serialize(
            pool_id=pool_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "AgentsProfileAgentProfilePool",
            '400': "CommonBadRequestErrorBody",
            '401': "CommonUnauthorizedErrorBody",
            '403': "CommonForbiddenErrorBody",
            '404': "CommonNotFoundErrorBody",
            '500': "CommonInternalServerErrorBody",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def agent_profile_pool_get_with_http_info(
        self,
        pool_id: Annotated[StrictStr, Field(description="The ID of the agent profile pool")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[AgentsProfileAgentProfilePool]:
        """Get Agent Profile Pool

        Get an agent profile pool by ID

        :param pool_id: The ID of the agent profile pool (required)
        :type pool_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._agent_profile_pool_get_serialize(
            pool_id=pool_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "AgentsProfileAgentProfilePool",
            '400': "CommonBadRequestErrorBody",
            '401': "CommonUnauthorizedErrorBody",
            '403': "CommonForbiddenErrorBody",
            '404': "CommonNotFoundErrorBody",
            '500': "CommonInternalServerErrorBody",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def agent_profile_pool_get_without_preload_content(
        self,
        pool_id: Annotated[StrictStr, Field(description="The ID of the agent profile pool")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get Agent Profile Pool

        Get an agent profile pool by ID

        :param pool_id: The ID of the agent profile pool (required)
        :type pool_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._agent_profile_pool_get_serialize(
            pool_id=pool_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "AgentsProfileAgentProfilePool",
            '400': "CommonBadRequestErrorBody",
            '401': "CommonUnauthorizedErrorBody",
            '403': "CommonForbiddenErrorBody",
            '404': "CommonNotFoundErrorBody",
            '500': "CommonInternalServerErrorBody",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _agent_profile_pool_get_serialize(
        self,
        pool_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if pool_id is not None:
            _path_params['poolId'] = pool_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'ApiKeyAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/agent-profile-pools/{poolId}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def agent_profile_pool_members_add(
        self,
        pool_id: Annotated[StrictStr, Field(description="The ID of the agent profile pool")],
        agents_profile_add_profiles_to_pool_request: Annotated[AgentsProfileAddProfilesToPoolRequest, Field(description="Profile IDs to add")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> None:
        """Add Profiles to Pool

        Add profiles to a pool

        :param pool_id: The ID of the agent profile pool (required)
        :type pool_id: str
        :param agents_profile_add_profiles_to_pool_request: Profile IDs to add (required)
        :type agents_profile_add_profiles_to_pool_request: AgentsProfileAddProfilesToPoolRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._agent_profile_pool_members_add_serialize(
            pool_id=pool_id,
            agents_profile_add_profiles_to_pool_request=agents_profile_add_profiles_to_pool_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '204': None,
            '400': "CommonBadRequestErrorBody",
            '401': "CommonUnauthorizedErrorBody",
            '403': "CommonForbiddenErrorBody",
            '404': "CommonNotFoundErrorBody",
            '500': "CommonInternalServerErrorBody",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def agent_profile_pool_members_add_with_http_info(
        self,
        pool_id: Annotated[StrictStr, Field(description="The ID of the agent profile pool")],
        agents_profile_add_profiles_to_pool_request: Annotated[AgentsProfileAddProfilesToPoolRequest, Field(description="Profile IDs to add")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[None]:
        """Add Profiles to Pool

        Add profiles to a pool

        :param pool_id: The ID of the agent profile pool (required)
        :type pool_id: str
        :param agents_profile_add_profiles_to_pool_request: Profile IDs to add (required)
        :type agents_profile_add_profiles_to_pool_request: AgentsProfileAddProfilesToPoolRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._agent_profile_pool_members_add_serialize(
            pool_id=pool_id,
            agents_profile_add_profiles_to_pool_request=agents_profile_add_profiles_to_pool_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '204': None,
            '400': "CommonBadRequestErrorBody",
            '401': "CommonUnauthorizedErrorBody",
            '403': "CommonForbiddenErrorBody",
            '404': "CommonNotFoundErrorBody",
            '500': "CommonInternalServerErrorBody",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def agent_profile_pool_members_add_without_preload_content(
        self,
        pool_id: Annotated[StrictStr, Field(description="The ID of the agent profile pool")],
        agents_profile_add_profiles_to_pool_request: Annotated[AgentsProfileAddProfilesToPoolRequest, Field(description="Profile IDs to add")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Add Profiles to Pool

        Add profiles to a pool

        :param pool_id: The ID of the agent profile pool (required)
        :type pool_id: str
        :param agents_profile_add_profiles_to_pool_request: Profile IDs to add (required)
        :type agents_profile_add_profiles_to_pool_request: AgentsProfileAddProfilesToPoolRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._agent_profile_pool_members_add_serialize(
            pool_id=pool_id,
            agents_profile_add_profiles_to_pool_request=agents_profile_add_profiles_to_pool_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '204': None,
            '400': "CommonBadRequestErrorBody",
            '401': "CommonUnauthorizedErrorBody",
            '403': "CommonForbiddenErrorBody",
            '404': "CommonNotFoundErrorBody",
            '500': "CommonInternalServerErrorBody",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _agent_profile_pool_members_add_serialize(
        self,
        pool_id,
        agents_profile_add_profiles_to_pool_request,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if pool_id is not None:
            _path_params['poolId'] = pool_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if agents_profile_add_profiles_to_pool_request is not None:
            _body_params = agents_profile_add_profiles_to_pool_request


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'ApiKeyAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/agent-profile-pools/{poolId}/members',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def agent_profile_pool_members_list(
        self,
        pool_id: Annotated[StrictStr, Field(description="The ID of the agent profile pool")],
        page_size: Optional[StrictInt] = None,
        page: Optional[StrictInt] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> AgentProfilePoolMembersList200Response:
        """List Pool Members

        List all profiles in a pool

        :param pool_id: The ID of the agent profile pool (required)
        :type pool_id: str
        :param page_size:
        :type page_size: int
        :param page:
        :type page: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._agent_profile_pool_members_list_serialize(
            pool_id=pool_id,
            page_size=page_size,
            page=page,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "AgentProfilePoolMembersList200Response",
            '400': "CommonBadRequestErrorBody",
            '401': "CommonUnauthorizedErrorBody",
            '403': "CommonForbiddenErrorBody",
            '404': "CommonNotFoundErrorBody",
            '500': "CommonInternalServerErrorBody",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def agent_profile_pool_members_list_with_http_info(
        self,
        pool_id: Annotated[StrictStr, Field(description="The ID of the agent profile pool")],
        page_size: Optional[StrictInt] = None,
        page: Optional[StrictInt] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[AgentProfilePoolMembersList200Response]:
        """List Pool Members

        List all profiles in a pool

        :param pool_id: The ID of the agent profile pool (required)
        :type pool_id: str
        :param page_size:
        :type page_size: int
        :param page:
        :type page: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._agent_profile_pool_members_list_serialize(
            pool_id=pool_id,
            page_size=page_size,
            page=page,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "AgentProfilePoolMembersList200Response",
            '400': "CommonBadRequestErrorBody",
            '401': "CommonUnauthorizedErrorBody",
            '403': "CommonForbiddenErrorBody",
            '404': "CommonNotFoundErrorBody",
            '500': "CommonInternalServerErrorBody",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def agent_profile_pool_members_list_without_preload_content(
        self,
        pool_id: Annotated[StrictStr, Field(description="The ID of the agent profile pool")],
        page_size: Optional[StrictInt] = None,
        page: Optional[StrictInt] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """List Pool Members

        List all profiles in a pool

        :param pool_id: The ID of the agent profile pool (required)
        :type pool_id: str
        :param page_size:
        :type page_size: int
        :param page:
        :type page: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._agent_profile_pool_members_list_serialize(
            pool_id=pool_id,
            page_size=page_size,
            page=page,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "AgentProfilePoolMembersList200Response",
            '400': "CommonBadRequestErrorBody",
            '401': "CommonUnauthorizedErrorBody",
            '403': "CommonForbiddenErrorBody",
            '404': "CommonNotFoundErrorBody",
            '500': "CommonInternalServerErrorBody",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _agent_profile_pool_members_list_serialize(
        self,
        pool_id,
        page_size,
        page,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if pool_id is not None:
            _path_params['poolId'] = pool_id
        # process the query parameters
        if page_size is not None:
            
            _query_params.append(('pageSize', page_size))
            
        if page is not None:
            
            _query_params.append(('page', page))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'ApiKeyAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/agent-profile-pools/{poolId}/members',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def agent_profile_pool_members_remove(
        self,
        pool_id: Annotated[StrictStr, Field(description="The ID of the agent profile pool")],
        agents_profile_remove_profiles_from_pool_request: Annotated[AgentsProfileRemoveProfilesFromPoolRequest, Field(description="Profile IDs to remove")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> None:
        """Remove Profiles from Pool

        Remove profiles from a pool

        :param pool_id: The ID of the agent profile pool (required)
        :type pool_id: str
        :param agents_profile_remove_profiles_from_pool_request: Profile IDs to remove (required)
        :type agents_profile_remove_profiles_from_pool_request: AgentsProfileRemoveProfilesFromPoolRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._agent_profile_pool_members_remove_serialize(
            pool_id=pool_id,
            agents_profile_remove_profiles_from_pool_request=agents_profile_remove_profiles_from_pool_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '204': None,
            '400': "CommonBadRequestErrorBody",
            '401': "CommonUnauthorizedErrorBody",
            '403': "CommonForbiddenErrorBody",
            '404': "CommonNotFoundErrorBody",
            '500': "CommonInternalServerErrorBody",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def agent_profile_pool_members_remove_with_http_info(
        self,
        pool_id: Annotated[StrictStr, Field(description="The ID of the agent profile pool")],
        agents_profile_remove_profiles_from_pool_request: Annotated[AgentsProfileRemoveProfilesFromPoolRequest, Field(description="Profile IDs to remove")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[None]:
        """Remove Profiles from Pool

        Remove profiles from a pool

        :param pool_id: The ID of the agent profile pool (required)
        :type pool_id: str
        :param agents_profile_remove_profiles_from_pool_request: Profile IDs to remove (required)
        :type agents_profile_remove_profiles_from_pool_request: AgentsProfileRemoveProfilesFromPoolRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._agent_profile_pool_members_remove_serialize(
            pool_id=pool_id,
            agents_profile_remove_profiles_from_pool_request=agents_profile_remove_profiles_from_pool_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '204': None,
            '400': "CommonBadRequestErrorBody",
            '401': "CommonUnauthorizedErrorBody",
            '403': "CommonForbiddenErrorBody",
            '404': "CommonNotFoundErrorBody",
            '500': "CommonInternalServerErrorBody",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def agent_profile_pool_members_remove_without_preload_content(
        self,
        pool_id: Annotated[StrictStr, Field(description="The ID of the agent profile pool")],
        agents_profile_remove_profiles_from_pool_request: Annotated[AgentsProfileRemoveProfilesFromPoolRequest, Field(description="Profile IDs to remove")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Remove Profiles from Pool

        Remove profiles from a pool

        :param pool_id: The ID of the agent profile pool (required)
        :type pool_id: str
        :param agents_profile_remove_profiles_from_pool_request: Profile IDs to remove (required)
        :type agents_profile_remove_profiles_from_pool_request: AgentsProfileRemoveProfilesFromPoolRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._agent_profile_pool_members_remove_serialize(
            pool_id=pool_id,
            agents_profile_remove_profiles_from_pool_request=agents_profile_remove_profiles_from_pool_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '204': None,
            '400': "CommonBadRequestErrorBody",
            '401': "CommonUnauthorizedErrorBody",
            '403': "CommonForbiddenErrorBody",
            '404': "CommonNotFoundErrorBody",
            '500': "CommonInternalServerErrorBody",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _agent_profile_pool_members_remove_serialize(
        self,
        pool_id,
        agents_profile_remove_profiles_from_pool_request,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if pool_id is not None:
            _path_params['poolId'] = pool_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if agents_profile_remove_profiles_from_pool_request is not None:
            _body_params = agents_profile_remove_profiles_from_pool_request


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'ApiKeyAuth'
        ]

        return self.api_client.param_serialize(
            method='DELETE',
            resource_path='/agent-profile-pools/{poolId}/members',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def agent_profile_pool_update(
        self,
        pool_id: Annotated[StrictStr, Field(description="The ID of the agent profile pool")],
        agents_profile_update_agent_profile_pool_request: Annotated[AgentsProfileUpdateAgentProfilePoolRequest, Field(description="Fields to update")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> AgentsProfileAgentProfilePool:
        """Update Agent Profile Pool

        Update an existing agent profile pool

        :param pool_id: The ID of the agent profile pool (required)
        :type pool_id: str
        :param agents_profile_update_agent_profile_pool_request: Fields to update (required)
        :type agents_profile_update_agent_profile_pool_request: AgentsProfileUpdateAgentProfilePoolRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._agent_profile_pool_update_serialize(
            pool_id=pool_id,
            agents_profile_update_agent_profile_pool_request=agents_profile_update_agent_profile_pool_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "AgentsProfileAgentProfilePool",
            '400': "CommonBadRequestErrorBody",
            '401': "CommonUnauthorizedErrorBody",
            '403': "CommonForbiddenErrorBody",
            '404': "CommonNotFoundErrorBody",
            '500': "CommonInternalServerErrorBody",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def agent_profile_pool_update_with_http_info(
        self,
        pool_id: Annotated[StrictStr, Field(description="The ID of the agent profile pool")],
        agents_profile_update_agent_profile_pool_request: Annotated[AgentsProfileUpdateAgentProfilePoolRequest, Field(description="Fields to update")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[AgentsProfileAgentProfilePool]:
        """Update Agent Profile Pool

        Update an existing agent profile pool

        :param pool_id: The ID of the agent profile pool (required)
        :type pool_id: str
        :param agents_profile_update_agent_profile_pool_request: Fields to update (required)
        :type agents_profile_update_agent_profile_pool_request: AgentsProfileUpdateAgentProfilePoolRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._agent_profile_pool_update_serialize(
            pool_id=pool_id,
            agents_profile_update_agent_profile_pool_request=agents_profile_update_agent_profile_pool_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "AgentsProfileAgentProfilePool",
            '400': "CommonBadRequestErrorBody",
            '401': "CommonUnauthorizedErrorBody",
            '403': "CommonForbiddenErrorBody",
            '404': "CommonNotFoundErrorBody",
            '500': "CommonInternalServerErrorBody",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def agent_profile_pool_update_without_preload_content(
        self,
        pool_id: Annotated[StrictStr, Field(description="The ID of the agent profile pool")],
        agents_profile_update_agent_profile_pool_request: Annotated[AgentsProfileUpdateAgentProfilePoolRequest, Field(description="Fields to update")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Update Agent Profile Pool

        Update an existing agent profile pool

        :param pool_id: The ID of the agent profile pool (required)
        :type pool_id: str
        :param agents_profile_update_agent_profile_pool_request: Fields to update (required)
        :type agents_profile_update_agent_profile_pool_request: AgentsProfileUpdateAgentProfilePoolRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._agent_profile_pool_update_serialize(
            pool_id=pool_id,
            agents_profile_update_agent_profile_pool_request=agents_profile_update_agent_profile_pool_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "AgentsProfileAgentProfilePool",
            '400': "CommonBadRequestErrorBody",
            '401': "CommonUnauthorizedErrorBody",
            '403': "CommonForbiddenErrorBody",
            '404': "CommonNotFoundErrorBody",
            '500': "CommonInternalServerErrorBody",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _agent_profile_pool_update_serialize(
        self,
        pool_id,
        agents_profile_update_agent_profile_pool_request,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if pool_id is not None:
            _path_params['poolId'] = pool_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if agents_profile_update_agent_profile_pool_request is not None:
            _body_params = agents_profile_update_agent_profile_pool_request


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'ApiKeyAuth'
        ]

        return self.api_client.param_serialize(
            method='PATCH',
            resource_path='/agent-profile-pools/{poolId}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def agent_profile_pools_create(
        self,
        agents_profile_create_agent_profile_pool_request: Annotated[AgentsProfileCreateAgentProfilePoolRequest, Field(description="Agent profile pool to create")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> AgentsProfileAgentProfilePool:
        """Create Agent Profile Pool

        Create a new agent profile pool

        :param agents_profile_create_agent_profile_pool_request: Agent profile pool to create (required)
        :type agents_profile_create_agent_profile_pool_request: AgentsProfileCreateAgentProfilePoolRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._agent_profile_pools_create_serialize(
            agents_profile_create_agent_profile_pool_request=agents_profile_create_agent_profile_pool_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '201': "AgentsProfileAgentProfilePool",
            '400': "CommonBadRequestErrorBody",
            '401': "CommonUnauthorizedErrorBody",
            '403': "CommonForbiddenErrorBody",
            '404': "CommonNotFoundErrorBody",
            '500': "CommonInternalServerErrorBody",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def agent_profile_pools_create_with_http_info(
        self,
        agents_profile_create_agent_profile_pool_request: Annotated[AgentsProfileCreateAgentProfilePoolRequest, Field(description="Agent profile pool to create")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[AgentsProfileAgentProfilePool]:
        """Create Agent Profile Pool

        Create a new agent profile pool

        :param agents_profile_create_agent_profile_pool_request: Agent profile pool to create (required)
        :type agents_profile_create_agent_profile_pool_request: AgentsProfileCreateAgentProfilePoolRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._agent_profile_pools_create_serialize(
            agents_profile_create_agent_profile_pool_request=agents_profile_create_agent_profile_pool_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '201': "AgentsProfileAgentProfilePool",
            '400': "CommonBadRequestErrorBody",
            '401': "CommonUnauthorizedErrorBody",
            '403': "CommonForbiddenErrorBody",
            '404': "CommonNotFoundErrorBody",
            '500': "CommonInternalServerErrorBody",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def agent_profile_pools_create_without_preload_content(
        self,
        agents_profile_create_agent_profile_pool_request: Annotated[AgentsProfileCreateAgentProfilePoolRequest, Field(description="Agent profile pool to create")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Create Agent Profile Pool

        Create a new agent profile pool

        :param agents_profile_create_agent_profile_pool_request: Agent profile pool to create (required)
        :type agents_profile_create_agent_profile_pool_request: AgentsProfileCreateAgentProfilePoolRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._agent_profile_pools_create_serialize(
            agents_profile_create_agent_profile_pool_request=agents_profile_create_agent_profile_pool_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '201': "AgentsProfileAgentProfilePool",
            '400': "CommonBadRequestErrorBody",
            '401': "CommonUnauthorizedErrorBody",
            '403': "CommonForbiddenErrorBody",
            '404': "CommonNotFoundErrorBody",
            '500': "CommonInternalServerErrorBody",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _agent_profile_pools_create_serialize(
        self,
        agents_profile_create_agent_profile_pool_request,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if agents_profile_create_agent_profile_pool_request is not None:
            _body_params = agents_profile_create_agent_profile_pool_request


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'ApiKeyAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/agent-profile-pools',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def agent_profile_pools_list(
        self,
        organization_id: Annotated[Optional[StrictStr], Field(description="Filter by organization ID")] = None,
        page_size: Optional[StrictInt] = None,
        page: Optional[StrictInt] = None,
        search_name: Annotated[Optional[StrictStr], Field(description="Search pools by name (partial match)")] = None,
        sort_field: Optional[AgentsProfilePoolSortField] = None,
        sort_direction: Optional[CommonSortDirection] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> AgentProfilePoolsList200Response:
        """List Agent Profile Pools

        List all agent profile pools for an organization

        :param organization_id: Filter by organization ID
        :type organization_id: str
        :param page_size:
        :type page_size: int
        :param page:
        :type page: int
        :param search_name: Search pools by name (partial match)
        :type search_name: str
        :param sort_field:
        :type sort_field: AgentsProfilePoolSortField
        :param sort_direction:
        :type sort_direction: CommonSortDirection
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._agent_profile_pools_list_serialize(
            organization_id=organization_id,
            page_size=page_size,
            page=page,
            search_name=search_name,
            sort_field=sort_field,
            sort_direction=sort_direction,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "AgentProfilePoolsList200Response",
            '400': "CommonBadRequestErrorBody",
            '401': "CommonUnauthorizedErrorBody",
            '403': "CommonForbiddenErrorBody",
            '404': "CommonNotFoundErrorBody",
            '500': "CommonInternalServerErrorBody",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def agent_profile_pools_list_with_http_info(
        self,
        organization_id: Annotated[Optional[StrictStr], Field(description="Filter by organization ID")] = None,
        page_size: Optional[StrictInt] = None,
        page: Optional[StrictInt] = None,
        search_name: Annotated[Optional[StrictStr], Field(description="Search pools by name (partial match)")] = None,
        sort_field: Optional[AgentsProfilePoolSortField] = None,
        sort_direction: Optional[CommonSortDirection] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[AgentProfilePoolsList200Response]:
        """List Agent Profile Pools

        List all agent profile pools for an organization

        :param organization_id: Filter by organization ID
        :type organization_id: str
        :param page_size:
        :type page_size: int
        :param page:
        :type page: int
        :param search_name: Search pools by name (partial match)
        :type search_name: str
        :param sort_field:
        :type sort_field: AgentsProfilePoolSortField
        :param sort_direction:
        :type sort_direction: CommonSortDirection
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._agent_profile_pools_list_serialize(
            organization_id=organization_id,
            page_size=page_size,
            page=page,
            search_name=search_name,
            sort_field=sort_field,
            sort_direction=sort_direction,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "AgentProfilePoolsList200Response",
            '400': "CommonBadRequestErrorBody",
            '401': "CommonUnauthorizedErrorBody",
            '403': "CommonForbiddenErrorBody",
            '404': "CommonNotFoundErrorBody",
            '500': "CommonInternalServerErrorBody",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def agent_profile_pools_list_without_preload_content(
        self,
        organization_id: Annotated[Optional[StrictStr], Field(description="Filter by organization ID")] = None,
        page_size: Optional[StrictInt] = None,
        page: Optional[StrictInt] = None,
        search_name: Annotated[Optional[StrictStr], Field(description="Search pools by name (partial match)")] = None,
        sort_field: Optional[AgentsProfilePoolSortField] = None,
        sort_direction: Optional[CommonSortDirection] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """List Agent Profile Pools

        List all agent profile pools for an organization

        :param organization_id: Filter by organization ID
        :type organization_id: str
        :param page_size:
        :type page_size: int
        :param page:
        :type page: int
        :param search_name: Search pools by name (partial match)
        :type search_name: str
        :param sort_field:
        :type sort_field: AgentsProfilePoolSortField
        :param sort_direction:
        :type sort_direction: CommonSortDirection
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._agent_profile_pools_list_serialize(
            organization_id=organization_id,
            page_size=page_size,
            page=page,
            search_name=search_name,
            sort_field=sort_field,
            sort_direction=sort_direction,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "AgentProfilePoolsList200Response",
            '400': "CommonBadRequestErrorBody",
            '401': "CommonUnauthorizedErrorBody",
            '403': "CommonForbiddenErrorBody",
            '404': "CommonNotFoundErrorBody",
            '500': "CommonInternalServerErrorBody",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _agent_profile_pools_list_serialize(
        self,
        organization_id,
        page_size,
        page,
        search_name,
        sort_field,
        sort_direction,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if organization_id is not None:
            
            _query_params.append(('organizationId', organization_id))
            
        if page_size is not None:
            
            _query_params.append(('pageSize', page_size))
            
        if page is not None:
            
            _query_params.append(('page', page))
            
        if search_name is not None:
            
            _query_params.append(('searchName', search_name))
            
        if sort_field is not None:
            
            _query_params.append(('sortField', sort_field.value))
            
        if sort_direction is not None:
            
            _query_params.append(('sortDirection', sort_direction.value))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'ApiKeyAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/agent-profile-pools',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )


